@@ -2,20 +2,21 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <limits.h>
 
 #include <errno.h>
 #include <getopt.h>
 
-#define COMPARE_MODE_SET \
+#define HASH_CHECK_MODE_SET \
 {\
 	switch(optarg[0])\
 	{\
 	case '1':\
-		oparg->COMPARE_MODE = BEFORE;\
+		oparg->CHECK_MODE = BEFORE;\
 		break;\
 \
 	case '2':\
-		oparg->COMPARE_MODE = AFTER;\
+		oparg->CHECK_MODE = AFTER;\
 		break;\
 \
 	default:\
@@ -37,7 +38,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	int result;
 
 	// 引数解析
-	while((result = getopt(argc, argv, "1:5:0b:c:iIlLmMot:vw:")) != -1)
+	while((result = getopt(argc, argv, "1:5:0b:c:iIlLmMor:t:vw:")) != -1)
 	{
 		switch(result)
 		{
@@ -46,9 +47,9 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			{
 				oparg->EFFECT = EXIST;
 			}
-			oparg->C = ONE;
+			oparg->CHECK = ONE;
 
-			COMPARE_MODE_SET
+			HASH_CHECK_MODE_SET
 			break;
 
 		case '5':	// MD5SUMでチェックする
@@ -56,9 +57,9 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			{
 				oparg->EFFECT = EXIST;
 			}
-			oparg->C = FIVE;
+			oparg->CHECK = FIVE;
 
-			COMPARE_MODE_SET
+			HASH_CHECK_MODE_SET
 			break;
 
 		case '0':	// コンペアを行わない
@@ -66,8 +67,8 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			{
 				oparg->EFFECT = EXIST;
 			}
-			oparg->C = NOT;
-			oparg->COMPARE_MODE = NOT;
+			oparg->CHECK = NOT;
+			oparg->CHECK_MODE = NOT;
 			break;
 
 		case 'b':	// バッファサイズを指定
@@ -80,6 +81,13 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 				errno = 0;
 				// atoiは使うべきではない、らしい
 				off_t b_tmp = strtoll(optarg, &endptr, 10);
+
+				if(b_tmp > INT_MAX)
+				{
+					fprintf(stderr, "バッファサイズの上限は2000MBです\n");
+					exit(EXIT_FAILURE);
+				}
+
 				if((endptr[0] != '\0') || (errno != 0) || (b_tmp < 2))
 				{
 					fprintf(stderr, "バッファの値が正しくありません。\n");
@@ -96,9 +104,9 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			{
 				oparg->EFFECT = EXIST;
 			}
-			oparg->C = MEMCMP;
+			oparg->CHECK = MEMCMP;
 
-			COMPARE_MODE_SET
+			HASH_CHECK_MODE_SET
 			break;
 
 		case 'i':	// 上書き時に確認する
@@ -158,6 +166,16 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			fprintf(stderr, "-oオプションは無視されます\n");
 			break;
 
+		case 'r':	// MD5SUMでチェックする
+			if(oparg->EFFECT == NOT)
+			{
+				oparg->EFFECT = EXIST;
+			}
+			oparg->CHECK = V_FIVE;
+
+			HASH_CHECK_MODE_SET
+			break;
+
 		case 't':	// スレッドモード
 			if(oparg->EFFECT == NOT)
 			{
@@ -240,13 +258,13 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 		fprintf(stderr, "引数が正しくありません\n");
 		exit(EXIT_FAILURE);
 	}
-	else if((oparg->C == MEMCMP) && (oparg->L == LOG))
+	else if((oparg->CHECK == MEMCMP) && (oparg->L == LOG))
 	{
 		fprintf(stderr, "-lオプションはSHA-1、もしくはMD5で比較する場合のみ有効です\n");
 		exit(EXIT_FAILURE);
 	}
 /*
-	else if(oparg->C == NOT)
+	else if(oparg->CHECK == NOT)
 	{
 		fprintf(stderr, "コンペアオプションが無効になっています\n");
 		exit(EXIT_FAILURE);
