@@ -4,7 +4,7 @@
 #include "replace_string.h" // inline
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
-#include "write_log_compare.h" // inline
+#include "write_log_hash_check.h" // inline
 
 #include <unistd.h>
 
@@ -67,7 +67,7 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 	// 特殊文字を置換済みの場合、'や"で括ると動作しなくなる
 	// 'で括る場合、文字列中に'があると動作しない。
 	// なので"でくくる。
-	if(oparg->C == ONE)
+	if(oparg->CHECK == ONE)
 	{
 		sprintf(command_from, "%s%s%s%s", "sha1sum -- ", "\"", re_from, "\"");
 		sprintf(command_to, "%s%s%s%s", "sha1sum -- ", "\"", re_to, "\"");
@@ -143,7 +143,7 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 			// MD5 == 32桁　SHA-1 == 40桁
 			if((strcmp(ffrom, tto) == 0) && ((strlen(ffrom) == 32) || (strlen(ffrom) == 40)))
 			{
-				cpinfo->compare = true;
+				cpinfo->hash_check = true;
 
 				if(oparg->V == VERBOS)
 				{
@@ -154,18 +154,18 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 
 				if(oparg->L == LOG)
 				{
-					write_log_compare(cpinfo, ffrom, tto, sdir, cpdd, true);
+					write_log_hash_check(cpinfo, ffrom, tto, sdir, cpdd, true);
 				}
 			}
 			else
 			{
 				print_error(__func__, __FILE__, __LINE__, cpdd);
 				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->to);
-				write_log_compare(cpinfo, ffrom, tto, sdir, cpdd, false);
+				write_log_hash_check(cpinfo, ffrom, tto, sdir, cpdd, false);
 				unlink(cpinfo->to);
 				cpinfo->write = false;
 				// falseで初期化しているので要らないはず
-				//cpinfo->compare = false;
+				//cpinfo->hash_check = false;
 			}
 		}
 		else
@@ -174,7 +174,7 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 			fprintf(stderr, "コンペアに失敗しました\n");
 			fprintf(stderr, "%s\n", cpinfo->from);
 			fprintf(stderr, "%s\n", cpinfo->to);
-			write_log_compare(cpinfo, "NULL", "NULL", sdir, cpdd, false);
+			write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
 		}
 	}
 	else
@@ -183,7 +183,7 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 		fprintf(stderr, "コンペアに失敗しました\n");
 		fprintf(stderr, "%s\n", cpinfo->from);
 		fprintf(stderr, "%s\n", cpinfo->to);
-		write_log_compare(cpinfo, "NULL", "NULL", sdir, cpdd, false);
+		write_log_hash_check(cpinfo, "NULL", "NULL", sdir, cpdd, false);
 	}
 
 	// 念のため、pipe詰まり対策
