@@ -1,6 +1,6 @@
 #include <stdio.h>
 
-static char version[] = "0.10.1 beta";
+static char version[] = "0.10.2 beta";
 
 // 関数プロトタイプ
 void help(void);
@@ -15,23 +15,23 @@ void help()
 	puts("sourceからdestへコピーする。optionとsourceは複数可。destが存在しない場合は自動的に作成する。");
 	puts("");
 	puts("オプション");
-	puts(" -1 MODE    SHA-1で比較する。");
+	puts(" -1 MODE    SHA-1でコンペアを行う。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後に比較する。");
 	puts("            一致しなかった場合はdestを削除する。");
 	puts("            (例 : snowcp -1 1 source dest)");
 	puts("");
-	puts(" -5 MODE    MD5で比較する。");
+	puts(" -5 MODE    MD5でコンペアを行う。");
 	puts("            MODEが1の場合はコピー直後に、");
 	puts("            2の場合は全コピー終了後に比較する。");
 	puts("            一致しなかった場合はdestを削除する。");
 	puts("            (例 : snowcp -5 1 source dest)");
 	puts("");
-	puts(" -0         コンペアを行わない。");
-	puts("            (-1、-5、-cオプションを無効にする。)");
+	puts(" -0         ベリファイ・コンペアを行わない。");
+	puts("            (-1、-5、-c、-rオプションを無効にする。)");
 	puts("");
 	puts(" -b NUMBER  バッファの量を指定する（MB単位）。");
-	puts("            (例 : snowcp -b 128 source dest)");
+	puts("            (例 : snowcp -b 64 source dest)");
 	puts("");
 	puts(" -c MODE    memcmpで比較する。");
 	puts("            MODEが1の場合はコピー直後に、");
@@ -54,14 +54,14 @@ void help()
 	puts(" -I         -iオプションを無効にする。");
 	puts("            (例 : snowcp -I source dest)");
 	puts("");
-	puts(" -l         コンペアのログを保存する。");
+	puts(" -l         ベリファイ・コンペアのログを保存する。");
 	puts("            -cオプションのログは保存しない。");
 	puts("            (例 : snowcp -1 2 -l source dest)");
 	puts("");
 	puts(" -L         -lオプションを無効にする。");
 	puts("            (例 : snowcp -L source dest)");
 	puts("");
-	puts(" -m         ファイルを移動する。");
+	puts(" -m         コピー終了後、コピー元を削除する。");
 	puts("            (例 : snowcp -m source dest)");
 	puts("");
 	puts(" -M         -mオプションを無効にする。");
@@ -70,6 +70,12 @@ void help()
 	puts(" -o         設定を保存する。");
 	puts("            (例 : snowcp -o)");
 	puts("");
+	puts(" -r MODE    ベリファイを行う。");
+	puts("            MODEが1の場合はコピー直後に、");
+	puts("            2の場合は全コピー終了後にベリファイを実行する。");
+	puts("            一致しなかった場合はdestを削除する。");
+	puts("            (例 : snowcp -r 1 source dest)");
+	puts("");
 	puts(" -t MODE    スレッドモードを指定する。");
 	puts("            MODEが1の場合は常に同一ドライブモード、");
 	puts("            2の場合は常に別ドライブモード、");
