@@ -6,7 +6,7 @@
 #include <stdlib.h>
 
 #include <signal.h>
-#include <unistd.h> 
+#include <unistd.h>
 
 // 関数プロトタイプ
 void set_signal(void);
@@ -35,13 +35,15 @@ void set_signal(void)
 *******************************************************************************/
 void handler(int sig)
 {
-	puts("");
-	puts("ERROR!");
-	printf("signal number = %d\n", sig);
+	fprintf(stderr, "\n");
+	fprintf(stderr, "ERROR!");
+	fprintf(stderr, "signal number = %d\n", sig);
+
 	if(write_now != NULL)
 	{
 		unlink(write_now);
-		printf("書き込み中の %s を削除しました\n", write_now);
+		fprintf(stderr, "書き込み中の %s を削除しました\n", write_now);
 	}
+
 	exit(EXIT_FAILURE);
 }
