@@ -1,5 +1,5 @@
-#ifndef INCLUDED_STRUCT_COPIEDDATA_H
-#define INCLUDED_STRUCT_COPIEDDATA_H
+#ifndef STRUCT_COPIED_DATA_H
+#define STRUCT_COPIED_DATA_H
 
 #include <sys/types.h>
 
