@@ -1,5 +1,5 @@
-#ifndef INCLUDED_XMALLOC_H
-#define INCLUDED_XMALLOC_H
+#ifndef XMALLOC_H
+#define XMALLOC_H
 
 #include <stdio.h>
 #include <stdlib.h>
